DATA_DIR = "/usr/local/share"
APP_ID = "org.gnome.tweaks"
PKG_DATA_DIR = "/usr/local/share/gnome-tweaks"
GSETTINGS_SCHEMA_DIR = "/usr/local/share/glib-2.0/schemas"
TWEAK_DIR = "/usr/local/lib/python3.12/site-packages/gtweak/tweaks"
VERSION = "49.0"
LOCALE_DIR = "/usr/local/share/locale"
PROFILE = "default"

IS_DEVEL = PROFILE == "development"
